@@ -12,6 +12,12 @@ START = 'start'
 STOP = 'stop'
 RESTART = 'restart'
 
+RUNNING = 'running'
+PAUSED = 'paused'
+
+PENDING = 'pending'
+COMPLETE = 'complete'
+
 OK = 'ok'
 DISABLED = 'disabled'
 
@@ -36,9 +42,9 @@ DEFAULT_DATA_PATH = '/var/lib/pritunl'
 DEFAULT_KEY_BITS = 4096
 DEFAULT_DH_PARAM_BITS = 1536
 DEFAULT_ORG_POOL_SIZE = 1
-DEFAULT_USER_POOL_SIZE = 8
-DEFAULT_SERVER_USER_POOL_SIZE = 4
-DEFAULT_SERVER_POOL_SIZE = 0
+DEFAULT_USER_POOL_SIZE = 6
+DEFAULT_SERVER_USER_POOL_SIZE = 2
+DEFAULT_SERVER_POOL_SIZE = 2
 DEFAULT_DH_PARAM_BITS_POOL = ['1536']
 DEFAULT_OTP_SECRET_LEN = 16
 DEFAULT_SERVER_LOG_LINES = 1024
@@ -48,7 +54,7 @@ SUBSCRIPTION_SERVER = 'https://app.pritunl.com/subscription'
 POSTMARK_SERVER = 'https://api.postmarkapp.com/email'
 UPDATE_CHECK_RATE = 3600
 ENV_PREFIX = APP_NAME
-LOG_LIMIT = 100
+LOG_LIMIT = 50
 EVENT_TTL = 60
 RATE_LIMIT_SLEEP = 0.5
 SERVER_STATUS_RATE = 10
@@ -69,7 +75,7 @@ LOCALHOST_IP_TTL = 30
 AUTH_SIG_STRING_MAX_LEN = 10240
 AUTH_TIME_WINDOW = 300
 OTP_CACHE_TTL = 43200
-SUB_OFF = False
+SUB_OFF = True
 IP_REGEX = r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}'
 SAFE_PUB_SUBNETS = {'50.203.224.0/24'}
 VALID_DH_PARAM_BITS = (1024, 1536, 2048, 3072, 4096)
@@ -396,6 +402,10 @@ cert %s
 key %s
 verb 2
 mute 3
+nobind
+reneg-sec 604800
+sndbuf 100000
+rcvbuf 100000
 """
 
 OVPN_INLINE_CLIENT_CONF = """# %s
@@ -407,6 +417,10 @@ nobind
 persist-tun
 verb 2
 mute 3
+nobind
+reneg-sec 604800
+sndbuf 100000
+rcvbuf 100000
 """
 
 # Script will run in python 2 and 3
