@@ -471,16 +471,38 @@ class Server(Config):
 
         dh_pool_path = cache_db.set_pop('dh_pool_%s' % self.dh_param_bits)
         if dh_pool_path:
-            cache_db.publish('servers_pool', 'update')
+            while True:
+                dh_state = cache_db.dict_get('dh_pool_state', dh_pool_path)
+                if dh_state == COMPLETE:
+                    cache_db.dict_remove('dh_pool_state', dh_pool_path)
+                    break
+                elif dh_state != PENDING:
+                    self._generate_dh_param()
+                    return
+                for msg in cache_db.subscribe('dh_pool', timeout=10):
+                    if msg == 'update':
+                        break
+            if not os.path.exists(dh_pool_path):
+                self._generate_dh_param()
+                return
             os.rename(dh_pool_path, self.dh_param_path)
+            cache_db.publish('pooler', 'update')
         else:
-            args = [
-                'openssl', 'dhparam',
-                '-out', self.dh_param_path,
-                str(self.dh_param_bits),
-            ]
-            subprocess.check_call(args, stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE)
+            task_id = uuid.uuid4().hex
+            try:
+                cache_db.set_add('openssl_tasks', task_id)
+                cache_db.publish('pooler', 'update')
+
+                args = [
+                    'openssl', 'dhparam',
+                    '-out', self.dh_param_path,
+                    str(self.dh_param_bits),
+                ]
+                subprocess.check_call(args, stdout=subprocess.PIPE,
+                    stderr=subprocess.PIPE)
+            finally:
+                cache_db.set_remove('openssl_tasks', task_id)
+                cache_db.publish('pooler', 'update')
 
     def _parse_network(self, network):
         network_split = network.split('/')
