@@ -11,4 +11,4 @@ cp ../../arch/production/pritunl.install ./
 TAR_SHA256=$(sha256sum $VERSION.tar.gz | cut -d' ' -f1)
 sed -i -e 's/CHANGE_ME/'$TAR_SHA256'/g' PKGBUILD
 
-makepkg --source
+mkaurball
